# 02-Spectral-index.py.     I. Marti-Vidal.      IMPRS Blackboard Lectures 2011.
# MONTE CARLO ESTIMATE OF THE UNCERTAINTY IN THE OBSERVED SPECTRAL INDEX.

import numpy as np
import pylab as pl

# Set parameters:

flux1 = 0.010      # Flux at frequency 1 (Jy, for instance)
errflux1 = 0.001   # Flux error at frequency 1
nu1 = 5.0          # Frequency 1 (GHz, for instance)

flux2 = 0.020      # Flux at frequency 2
errflux2 = 0.0015  # Flux error at frequency 2
nu2 = 1.7          #Frequency 2

ndata = 10000      # Number of data

# Simulate:

alpha = np.log(flux1/flux2)/np.log(nu1/nu2)  # Real value of the spectral index
erralpha = np.sqrt((errflux1/flux1)**2.+(errflux2/flux2)**2.)/np.log(nu1/nu2) # From error propagation

print "\n Number of points: ",ndata
print "\n - True alpha: ",alpha," +/- ",erralpha

fl1vec = np.random.normal(flux1,errflux1,ndata)   # Vector of random fluxes (frequency 1)
fl2vec = np.random.normal(flux2,errflux2,ndata)   # Vector of random fluxes (frequency 1)
alphavec = np.log(fl1vec/fl2vec)/np.log(nu1/nu2)  # Distribution of spectral indices

print " - Monte Carlo alpha: ",np.average(alphavec)," +/- ",np.std(alphavec)


